@@ -23,6 +23,10 @@ def local_node_css_package(package_name: str, path: Optional[str] = None, recurs
 def npm_node_package(package_name: str, version: Optional[str] = None, path: str = '', **kwargs):
     attrs = ''
     for key, value in kwargs.items():
+        if isinstance(value, bool):
+            if value:
+                attrs += f' {key.replace("_", "-")}'
+            continue
         attrs += f' {key.replace('_', '-')}="{value}"'
 
     url = f'https://cdn.jsdelivr.net/npm/{package_name}'
